
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is libguac-client-rdp.
 *
 * The Initial Developer of the Original Code is
 * Michael Jumper.
 * Portions created by the Initial Developer are Copyright (C) 2011
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include <stdint.h>

#include <guacamole/unicode.h>

void guac_rdp_utf16_to_utf8(const unsigned char* utf16, int length,
        char* utf8, int size) {

    int i;
    const uint16_t* in_codepoint = (const uint16_t*) utf16;

    /* For each UTF-16 character */
    for (i=0; i<length; i++) {

        /* Get next codepoint */
        uint16_t codepoint = *(in_codepoint++);

        /* Save codepoint as UTF-8 */
        int bytes_written = guac_utf8_write(codepoint, utf8, size);
        size -= bytes_written;
        utf8 += bytes_written;

    }

    /* Save NULL terminator */
    *(utf8++) = 0;

}

void guac_rdp_utf8_to_utf16(const unsigned char* utf8, int length,
        char* utf16, int size) {

    int i;
    uint16_t* out_codepoint = (uint16_t*) utf16;

    /* For each UTF-8 character */
    for (i=0; i<length; i++) {

        /* Get next codepoint */
        int codepoint;
        utf8 += guac_utf8_read((const char*) utf8, 4, &codepoint);

        /* Save codepoint as UTF-16 */
        *(out_codepoint++) = codepoint;

        /* Stop if buffer full */
        size -= 2;
        if (size < 2)
            break;

    }

}

